@@ -17,9 +17,9 @@
 
 import flask
 import flask_restful
+import http.client
 from oslo_log import log
 from oslo_policy import _checks as op_checks
-from six.moves import http_client
 
 from keystone.api._shared import json_home_relations
 from keystone.common import context
@@ -228,12 +228,13 @@ class TrustResource(ks_flask.ResourceBase):
         # rule check_str is ""
         if isinstance(rules, op_checks.TrueCheck):
             LOG.warning(
-                "The policy check string for rule \"identity:list_trusts\" has been overridden "
-                "to \"always true\". In the next release, this will cause the "
-                "\"identity:list_trusts\" action to be fully permissive as hardcoded "
-                "enforcement will be removed. To correct this issue, either stop overriding the "
-                "\"identity:list_trusts\" rule in config to accept the defaults, or explicitly "
-                "set a rule that is not empty."
+                "The policy check string for rule \"identity:list_trusts\" "
+                "has been overridden to \"always true\". In the next release, "
+                "this will cause the \"identity:list_trusts\" action to be "
+                "fully permissive as hardcoded enforcement will be removed. "
+                "To correct this issue, either stop overriding the "
+                "\"identity:list_trusts\" rule in config to accept the "
+                "defaults, or explicitly set a rule that is not empty."
             )
             if not flask.request.args:
                 # NOTE(morgan): Admin can list all trusts.
@@ -242,9 +243,11 @@ class TrustResource(ks_flask.ResourceBase):
         if not flask.request.args:
             trusts += PROVIDERS.trust_api.list_trusts()
         elif trustor_user_id:
-            trusts += PROVIDERS.trust_api.list_trusts_for_trustor(trustor_user_id)
+            trusts += PROVIDERS.trust_api.list_trusts_for_trustor(
+                trustor_user_id)
         elif trustee_user_id:
-            trusts += PROVIDERS.trust_api.list_trusts_for_trustee(trustee_user_id)
+            trusts += PROVIDERS.trust_api.list_trusts_for_trustee(
+                trustee_user_id)
 
         for trust in trusts:
             # get_trust returns roles, list_trusts does not
@@ -302,7 +305,7 @@ class TrustResource(ks_flask.ResourceBase):
             initiator=self.audit_initiator)
         _normalize_trust_expires_at(return_trust)
         _normalize_trust_roles(return_trust)
-        return self.wrap_member(return_trust), http_client.CREATED
+        return self.wrap_member(return_trust), http.client.CREATED
 
     def delete(self, trust_id):
         ENFORCER.enforce_call(action='identity:delete_trust',
@@ -333,7 +336,7 @@ class TrustResource(ks_flask.ResourceBase):
                 raise exception.ForbiddenAction(action=action)
         PROVIDERS.trust_api.delete_trust(trust_id,
                                          initiator=self.audit_initiator)
-        return '', http_client.NO_CONTENT
+        return '', http.client.NO_CONTENT
 
 
 # NOTE(morgan): Since this Resource is not being used with the automatic
