@@ -142,5 +142,9 @@ def render_token_response_from_model(token, include_catalog=True):
             token_reference['token'][key]['access_rules'] = (
                 token.application_credential['access_rules']
             )
+    if token.oauth2_thumbprint:
+        token_reference['token']['oauth2_credential'] = {
+            'x5t#S256': token.oauth2_thumbprint
+        }
 
     return token_reference
